@@ -16,7 +16,6 @@ logger = logging.getLogger(__name__)
 # Load the library
 # This ensures that we can find the library when we load _smelib
 libfile = get_full_libfile()
-logger.critical(libfile)
 cdll.LoadLibrary(libfile)
 from .smelib import _smelib
 
@@ -245,6 +244,8 @@ class SME_DLL:
             abundance structure to be passed (see Abund for more details)
         """
         abund = abund("sme", raw=True)
+        # TODO: does this make sense or should we fix the C code?
+        abund[np.isnan(abund)] = -12
         _smelib.InputAbund(abund)
 
     def Opacity(self):
